@@ -3,9 +3,11 @@ from collections import defaultdict
 from digitalguide.standardinteraktion.Action import readActions
 from digitalguide.standardinteraktion.Trigger import readTriggers
 
+from digitalguide.standardinteraktion.wegInteraktion import Weg
+
 
 class Interaktion:
-    def __init__(self, name, typ, states, actions, uebertrag_actions, next_interaktion):
+    def __init__(self, name, typ, states, actions, uebertrag_actions, next_interaktion, action_requirements):
         self.name = name
         self.typ = typ
         self.states = states
@@ -13,10 +15,13 @@ class Interaktion:
         self.uebertrag_actions = uebertrag_actions
         self.next_interaktion = next_interaktion
 
+        self.action_requirements = action_requirements
+
     @classmethod
     def from_excel_dict(cls, excel_dict_item):
         actions = defaultdict(list)
         states = defaultdict(list)
+        action_requirements = []
 
         poi_interaction, interaktion_dict = excel_dict_item
         poi_name, interaction_typ = poi_interaction
@@ -25,11 +30,12 @@ class Interaktion:
             weiter_dict = dict((x, y) for x, y in interaktion_dict["Next"])
             next_interaktion = "{}_{}".format(
                 weiter_dict["POI"], weiter_dict["Aktion"])
+            action_requirements.append(next_interaktion)
+
         else:
-            next_interaktion=None
+            next_interaktion = None
 
         if interaction_typ == "Aktion":
-            print(interaktion_dict)
             actions["{}".format(poi_name)] = readActions(
                 interaktion_dict["Aktion"])
 
@@ -44,18 +50,7 @@ class Interaktion:
                     "action": "{}_tipp".format(poi_name)}]
 
         elif interaction_typ == "Weg":
-            actions["{}_weg".format(poi_name)] = readActions(interaktion_dict["Weg"]
-                                                             + [("Return", "{}_WEG".format(poi_name.upper()))])
-
-            actions["{}_navigation".format(poi_name)] = readActions(
-                interaktion_dict["Navigation"])
-            actions["{}_tipp".format(poi_name)] = readActions(
-                interaktion_dict["Tipp"])
-
-            states["{}_WEG".format(poi_name.upper())] = readTriggers(interaktion_dict["trigger_navigation"], "{}_navigation".format(poi_name)) \
-                + readTriggers(interaktion_dict["trigger_weiter"], next_interaktion) \
-                + [{"handler": "TypeHandler", "type": "Update",
-                    "action": "{}_tipp".format(poi_name)}]
+            return Weg().from_excel_dict(excel_dict_item)
 
         elif interaction_typ == "Quizfrage":
             actions["{}_frage".format(poi_name)] = readActions(
@@ -203,4 +198,4 @@ class Interaktion:
         else:
             print("Der Interaktionstyp {} ist nicht bekannt!".format(interaction_typ))
 
-        return cls(poi_name, interaction_typ, states, actions, [], next_interaktion)
+        return cls(poi_name, interaction_typ, states, actions, [], next_interaktion, action_requirements)
